import javafx.animation.PathTransition;
import javafx.util.Duration;
import javafx.animation.Timeline;
import javafx.application.Application;
import javafx.scene.Scene;
import javafx.scene.layout.Pane;
import javafx.scene.paint.Color;
import javafx.scene.shape.Rectangle;
import javafx.scene.shape.Circle;
import javafx.stage.Stage;

/**
 * Demo of the JavaFX PathTransition class.
 *
 * @author Prof. Carl B. Struck
 * @version Copyright (c) SCCC Spring 2016 - SCCC West 
 */
public class JavaFXAnimation1 extends Application
{
    /**
     * Instantiates JavaFX Rectangle and Circle objects and places them on 
     * a PathTransition object in which the rectangle object follows the circle 
     * object.  The rectangle pauses when clicked by the mouse and begins to 
     * move again when the mouse button is released.
     * 
     * @param primaryStage a Stage window object
     */
    @Override
    public void start(Stage primaryStage)
    {
        Pane pane = new Pane();

        Circle circle = new Circle(250, 200, 150);
        circle.setFill(Color.WHITE);
        circle.setStroke(Color.WHITE);

        Rectangle rectangle = new Rectangle(0, 0, 30, 20);
        rectangle.setFill(Color.AQUAMARINE);
        rectangle.setStroke(Color.WHITE);

        pane.getChildren().addAll(circle, rectangle);

        // Create a path transition
        PathTransition path = new PathTransition();
        path.setDuration( Duration.millis(5000) );
        path.setPath(circle);
        path.setNode(rectangle);
        path.setOrientation(PathTransition.OrientationType.ORTHOGONAL_TO_TANGENT);
        path.setCycleCount(Timeline.INDEFINITE);
        path.setAutoReverse(true);
        path.play();

        // Set rectangle object on path to pause when it is clicked by 
        // the mouse and to play again when mouse button is released
        // (caused by setOnMousePressed() with Lambda expression 
        //  instead of setOnAction() )
        rectangle.setOnMousePressed( e -> path.pause() );
        rectangle.setOnMouseReleased( e -> path.play() );

        Scene scene = new Scene(pane, 500, 400);
        primaryStage.setTitle("Path Transition Demo");
        primaryStage.setScene(scene);
        primaryStage.show();
    }
}