package javafxevents6;

import javafx.application.Application;
import javafx.scene.Scene;
import javafx.geometry.Pos;
import javafx.scene.control.Label;
import javafx.scene.control.Button;
import javafx.scene.layout.BorderPane;
import javafx.scene.layout.StackPane;
import javafx.scene.layout.HBox;
import javafx.stage.Stage;
import javax.swing.JOptionPane;

/**
 * Demo of the JavaFX Button class and EventHandler interface.
 *
 * @author Prof. Carl B. Struck
 * @version Copyright (c) SCCC Fall 2014 - SCCC West 
 */
public class JavaFXEvents6 extends Application 
{
    /**
     * Instantiates two JavaFX Button controls and a event handlers that 
     * display messages when either Button is clicked.
     * 
     * @param primaryStage a Stage window object
     */
    @Override
    public void start(Stage primaryStage) 
    {
        BorderPane border = new BorderPane();
        StackPane stack = new StackPane();
        
        HBox hBox = new HBox(50);
        hBox.setAlignment(Pos.CENTER);

        stack.getChildren().add( new Label("Click button to open message box") );
        border.setTop(stack);
        
        Button buttonOK = new Button("OK");
        buttonOK.setOnAction( (e) -> 

        // Call the display 'OK' method.
        {
            displayOkMessage();
        } 
        
        );
        
        Button buttonCancel = new Button("Cancel");
        buttonCancel.setOnAction( (e) -> 
                
        // Displays a "Cancel" message in a JOptionPane.showMessageDialog window
        // and also to the console.
        {
            System.out.println("Cancel button was clicked"); 
            System.out.println("Does that make you feel canceled?");
            
            JOptionPane.showMessageDialog(null, "Cancel button was clicked" );
        } 
        
        );
        
        hBox.getChildren().addAll(buttonOK, buttonCancel);
        border.setBottom(hBox);

        Scene scene = new Scene(border, 400, 50);

        primaryStage.setTitle("Buttons and EventHandler Demo");
        primaryStage.setResizable(false);
        primaryStage.setScene(scene);
        primaryStage.show();
    }
    
    /**
    * Displays an "OK" message in a JOptionPane.showMessageDialog window
    * and also to the console.
    */
    public void displayOkMessage()
    {
        System.out.println("OK button was clicked"); 
        System.out.println("Does that make you feel OK?");
        
        JOptionPane.showMessageDialog(null, "OK button was clicked");
    }

    /**
     * The main() method is ignored in correctly deployed JavaFX application.
     * main() serves only as fallback in case the application can not be
     * launched through deployment artifacts, e.g., in IDEs with limited FX
     * support. NetBeans ignores main().
     *
     * @param args the String[] array command line parameter
     */
    public static void main(String[] args) 
    {
        launch(args);
    }
}
